@@ -2,7 +2,7 @@
 
 package Convert::TAP::Archive;
 {
-  $Convert::TAP::Archive::VERSION = '0.004';
+  $Convert::TAP::Archive::VERSION = '0.005';
 }
 
 use strict;
@@ -89,7 +89,7 @@ Convert::TAP::Archive - Read from a TAP archive and convert it for displaying
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -102,6 +102,11 @@ version 0.004
 
 =encoding utf8
 
+=head1 IMPORTANT NOTE
+
+B<THIS MODULE IS DEPRECATED!>
+Please see L<Archive::TAP::Convert> instead.
+
 =head1 ABOUT
 
 This modul can be of help for you if you have TAP archives (e.g. created with C<prove -a> and now you wish to have the content of this archives in a special format like HTML or JUnit (or whatever format).
@@ -135,6 +140,11 @@ No known issues.
 
 =item *
 
+This module is no longer maintained!
+Please see L<Archive::TAP::Convert> for the same funcionality.
+
+=item *
+
 L<Test::Harness>
 
 =item *
